@@ -9,7 +9,9 @@ use File::Spec;
 use File::Temp;
 use Test::Builder::Module;
 
-our $VERSION = '0.041';
+use overload '{}' => 'path';
+
+our $VERSION = '0.050';
 our @ISA = 'Test::Builder::Module';
 
 ##############################
@@ -119,12 +121,16 @@ sub clean {
     foreach my $file ( keys %{$self->{files}} ) {
     	unlink $self->path($file);
     };
-    foreach my $dir ( keys %{$self->{directories}} ) {
-    	rmdir $self->path($dir);
+    #get subdirs before parents
+    foreach my $dir (sort {length($b) <=> length($a)}
+		     keys %{$self->{directories}} ) {
+      rmdir $self->path($dir);
     };
-    rmdir $self->{dir};
+    my $rv = rmdir $self->{dir};
+    carp "$self->{dir}: $1" unless $rv;
+    return $rv;
 }
-    
+
 sub _path_map {
     my $self = shift;
     my %path;
